% Reading data from Excel file 'datafilename.xls'
[Z,endolabels]=xlsread(datafilename,endosheetname); % Z contains data base with endogenous variables
[D,dummylabels]=xlsread(datafilename,dummysheetname); % D contains data base with exogenous/dummy variables

% Check how xlsread.m read the data. xlsread.m (or Excel) is not very stable, so we have to make sure it did things right.
if size(endolabels,1)>1 % date column ended up as the first column of endolabels.
    serialdatenumbers=datenum(endolabels(2:end,1),'yyyy-mm-dd');
else                    % date column ended up as the first column of Z.
    serialdatenumbers=Z(:,1); % Matlab's internal representation of dates.
    Z=Z(:,2:size(Z,2)); % Remove date column.
end
if size(dummylabels,1)>1 % date column ended up as the first column of dummylabels.
    % Do nothing
else                    % date column ended up as the first column of D.
    D=D(:,2:size(D,2)); % Remove date column.
end

endolabels=endolabels(1,2:end); % Extracting labels of endogenous variables
dummylabels=dummylabels(1,2:end); % Extracting labels of exogenous/dummy variables

switch season
    case 1
        DateLabels=datestr(serialdatenumbers,10); % String with dates of the form Y1-99 (which simply means year 1999)
        DateLabels=strcat(repmat('Y1-',size(DateLabels,1),1),DateLabels(:,3:4));
    case 4  % Quarterly
        DateLabels=datestr(serialdatenumbers,17); % String with dates of the form Q1-99
    case 12 % Monthly
        DateLabels=datestr(serialdatenumbers,12); % String with dates of the form Mar99, then turned into format 03-99
        MonthNumber=MonthName2MonthNumber(DateLabels);
        DateLabels=strcat(MonthNumber,repmat('-',size(DateLabels,1),1),DateLabels(:,4:5));
    otherwise
        errordlg('Season must be 1, 4 or 12')
end

% Reading data properties from Excel file 'datafilename.xls'
[endoprop,endoproplabels]=xlsread(datafilename,endopropsheetname);
[dummyprop,dummyproplabels]=xlsread(datafilename,dummypropsheetname);
isexogenous=endoprop(:,1)';
isdifference=endoprop(:,2)';
%Annualized2Quarterly=find(endoprop(:,3))';
MeanFirstLag=endoprop(:,3);
SeasonalVars=endoprop(:,4)';
if isempty(dummyprop)==0
    isdomesticdummies=dummyprop(:,1)';
end

% Constructing estimation dates. 
samplestartyear=eval(strcat('19',DateLabels(1,4:5)));
if season==12
    samplestartperiod=eval(DateLabels(1,1:2));
else
    samplestartperiod=eval(DateLabels(1,2));
end
T=size(Z,1);
sampledates=[];
year=samplestartyear;
period=samplestartperiod;
i=1;
while i<=T
    while period<=season
        if i>T
            break
        end
        sampledates(i,1:3)=[i year period];
        period=period+1;
        i=i+1;
    end
    period=1;
    year=year+1;
end

% Detrending and demeaning selected variables using simple regression on constant and linear time trend.
if isnan(DeTrendVars)
    % Do nothing
else
    bigx= [ones(size(Z,1),1) (1:size(Z,1))'];
    for i=1:length(DeTrendVars)
        Z(:,DeTrendVars(i)) = Z(:,DeTrendVars(i)) - bigx*inv(bigx'*bigx)*bigx'*Z(:,DeTrendVars(i));
    end
end