function BlockedMatrix=BlockDiag(CellMatrix)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PURPOSE:     Creates a block-diagonal matrix of the r-by-1 cell CellMatrix
%
% INPUT:       CellMatrix       (r-by-1 Cell)
%
% OUTPUT:      BlockedMatrix    (Matrix)        Block diagonal matrix with blocks 
%                   CellMatrix{1},CellMatrix{2},...,CellMatrix{r}
%
% AUTHOR:      Mattias Villani, Research Department, Sveriges Riksbank and
%              Department of Statistics, Stockholm University. 
%              E-mail: mattias.villani@riksbank.se
% 
% 1st VER:     2000-08-03
% REVISED:     2004-06-30
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

CellMatrix=CellMatrix(:);
r=size(CellMatrix,1);
Rows=zeros(r,1);
cols=zeros(r,1);
for i=1:r
   [Rows(i),cols(i)]=size(CellMatrix{i});
end

BlockedMatrix=zeros(sum(Rows),sum(cols));
CumSumRows=[0;cumsum(Rows)];
CumSumcols=[0;cumsum(cols)];

for i=1:r
   BlockedMatrix(1+CumSumRows(i):CumSumRows(i+1),1+CumSumcols(i):CumSumcols(i+1))=CellMatrix{i};
end
